@@ -66,15 +66,15 @@ async def create_task(request: SoraVideoRequest, api_key: str, base_url: Optiona
             "768p": "1366x768",
             "1080p": "1920x1080",
         }
-        request.size = mapping.get(request.resolution) or request.size
+        request.size = mapping.get(request.resolution) or request.size or "1366x768"
 
-    elif request.model.startswith("vidu"):
+    elif request.model.startswith("vidu"):  # todo 视频模型 分辨率 映射
         mapping = {
             "512p": "512x512",
             "768p": "1366x768",
             "1080p": "1920x1080",
         }
-        request.size = mapping.get(request.resolution) or request.size
+        request.size = mapping.get(request.resolution) or request.size or "512x512"
 
     payload = [
         {
@@ -113,6 +113,17 @@ async def create_task(request: SoraVideoRequest, api_key: str, base_url: Optiona
                 }
                 for url in urls
             ]
+    elif request.image:
+        urls = request.image
+        if request.model.startswith(("vidu",)):
+            payload[0]["referenceImages"] = urls
+        else:
+            payload[0]["frameImages"] = [
+                {
+                    "inputImage": url
+                }
+                for url in urls
+            ]
 
     logger.debug(bjson(payload))
 
@@ -177,12 +188,12 @@ if __name__ == '__main__':
 
     logger.info(request)
 
-    arun(create_task(request, api_key="TdgJuoP9VEyeBBtzuF5q6E1ibdioHAyV"))
+    # arun(create_task(request, api_key="TdgJuoP9VEyeBBtzuF5q6E1ibdioHAyV"))
 
     # https://openai-dev.chatfire.cn/sys/webhook/runware?expr=%24..taskUUID
 
-    # task_id = "0ef0780a-7995-464c-b899-63cacf723518"
-    # arun(get_task(task_id))
+    task_id = "72f0462b-bc54-4941-bb97-918fa0e49167"
+    arun(get_task(task_id))
 
     # {
     #     "data": [
