@@ -10,12 +10,12 @@
 import time
 
 from meutils.pipe import *
-from meutils.io.files_utils import to_url
+from meutils.io.files_utils import to_url, to_base64
 from meutils.decorators.retry import retrying
 
 from meutils.llm.clients import AsyncClient
 from meutils.schemas.openai_types import CompletionRequest
-from meutils.schemas.video_types import VideoRequest
+from meutils.schemas.video_types import VideoRequest, SoraVideoRequest
 
 from meutils.db.redis_db import redis_aclient
 # from meutils.llm.check_utils import check_token_for_volc
@@ -26,67 +26,108 @@ from meutils.config_utils.lark_utils import get_next_token_for_polling, get_seri
 from fastapi import APIRouter, File, UploadFile, Query, Form, Depends, Request, HTTPException, status, BackgroundTasks
 
 # Please activate
-FEISHU_URL = "https://xchatllm.feishu.cn/sheets/GYCHsvI4qhnDPNtI4VPcdw2knEd?sheet=8W6kk8"  # 超刷
+FEISHU_URL = "https://xchatllm.feishu.cn/sheets/Z59Js10DbhT8wdt72LachSDlnlf?sheet=rcoDg7"
 
 
+# todo 剔除每天超过300w tokens的 确保稳定
 async def get_valid_token(tokens: Optional[list] = None, batch_size: Optional[int] = None, seed: int = 0,
                           recheck: bool = False):
     """返回 tokens
     api_key = np.random.choice(api_key.split())
 
     """
-    tokens = tokens or await get_series(FEISHU_URL, duplicated=True)
-    batch_size = batch_size or 1
+    api_key = tokens or await get_next_token_for_polling(
+        feishu_url=FEISHU_URL,
+        from_redis=True,
+        ttl=24 * 3600,
+        check_token=check_token_for_volc
+    )
+    if isinstance(api_key, list):  # 向下兼容
+        api_key = '\n'.join(api_key)
 
-    #     tokens = """
-    #     90f18a26-e4f1-4bea-b692-93d2883b3bcc
-    # 95b3f0ef-a93b-4e10-829a-d2274f448201""".split()
-    #     await redis_aclient.set("volc_tokens", "\n".join(tokens))
+    return api_key
 
-    if seed == 0 and (volc_tokens := await redis_aclient.get(f"volc_tokens")):  # 刷新
-        volc_tokens = volc_tokens.decode()
-        if recheck:
-            valid_tokens = await check_token_for_volc(volc_tokens.split('\n'))
-
-            volc_tokens = '\n'.join(valid_tokens)
-
-        return volc_tokens
-
-    valid_tokens = []
-    for token in tokens:
-        if token := await check_token_for_volc([token]):
-            valid_tokens += token
-
-            logger.debug(valid_tokens)
-            if len(valid_tokens) == batch_size:
-                _ = '\n'.join(valid_tokens)
-                await redis_aclient.set(f"volc_tokens", _, ex=2 * 3600)
-                # ttl =await redis_aclient.ttl(f"volc_tokens")
-
-                return _
+    # tokens = tokens or await get_series(FEISHU_URL, duplicated=True)
+    # batch_size = batch_size or 1
+    #
+    #
+    # if seed == 0 and (volc_tokens := await redis_aclient.get(f"volc_tokens")):  # 刷新
+    #     volc_tokens = volc_tokens.decode()
+    #     if recheck:
+    #         valid_tokens = await check_token_for_volc(volc_tokens.split('\n'))
+    #
+    #         volc_tokens = '\n'.join(valid_tokens)
+    #
+    #     return volc_tokens
+    #
+    # valid_tokens = []
+    # for token in tokens:
+    #     if token := await check_token_for_volc([token]):
+    #         valid_tokens += token
+    #
+    #         logger.debug(valid_tokens)
+    #         if len(valid_tokens) == batch_size:
+    #             _ = '\n'.join(valid_tokens)
+    #             await redis_aclient.set(f"volc_tokens", _, ex=2 * 3600)
+    #             # ttl =await redis_aclient.ttl(f"volc_tokens")
+    #
+    #             return _
 
 
 # check_image_and_video = partial(check, purpose='video and image')
 
 
 @retrying()
-async def create_task(request: Union[CompletionRequest, VideoRequest], api_key: Optional[str] = None):
+async def create_task(request: Union[CompletionRequest, VideoRequest, SoraVideoRequest], api_key: Optional[str] = None):
     # api_key = api_key or await get_next_token_for_polling(feishu_url=FEISHU_URL, check_token=check)
-    api_key = api_key or await get_valid_token()
+    # api_key = api_key or await get_valid_token()
+    #
+    # api_key = np.random.choice(api_key.split('\n'))  # todo 轮询
 
-    api_key = np.random.choice(api_key.split('\n'))  # todo 轮询
-
-    # feishu_url = "https://xchatllm.feishu.cn/sheets/Z59Js10DbhT8wdt72LachSDlnlf?sheet=rcoDg7"
-    # api_key = api_key or await get_next_token_for_polling(
-    #     feishu_url=feishu_url,
-    #     from_redis=True,
-    #     ttl=24 * 3600,
-    #     check_token=check
-    # )
+    api_key = api_key or await get_next_token_for_polling(
+        feishu_url=FEISHU_URL,
+        from_redis=True,
+        ttl=24 * 3600,
+        check_token=check_token_for_volc
+    )
 
     logger.debug(f"api_key: {api_key}")
-    if isinstance(request, VideoRequest):  # 兼容jimeng
-        request.prompt = f"{request.prompt} --duration {request.duration}"
+    if isinstance(request, SoraVideoRequest):  # todo 首尾帧 参考图
+        if request.model.startswith("doubao-seedance-1-0-pro"):  # "doubao-seedance-1-0-pro-fast-251015_1080p"
+            request.prompt = request.prompt.split('--', maxsplit=1)[0]  # 取消命令行参数
+            request.prompt = f"{request.prompt} --rt {request.ratio} --dur {request.seconds}"
+            if request.resolution:
+                request.prompt += f" --rs {request.resolution}"
+
+            payload = {
+                "model": request.model,
+
+                "content": [
+                    {
+                        "type": "text",
+                        "text": request.prompt
+                    }
+                ]
+            }
+            if request.input_reference:
+                images = await to_base64(request.input_reference)
+                if len(images) > 2:
+                    images = images[:2]
+
+                # 首尾帧
+                for role, image in zip(["first_frame", "last_frame"], images):
+                    _ = {
+                        "role": role,  # first_frame last_frame reference_image
+                        "type": "image_url",
+                        "image_url": {
+                            "url": image
+                        },
+                    }
+                    payload["content"] += [_]
+
+
+    elif isinstance(request, VideoRequest):  # 兼容jimeng
+        request.prompt = f"{request.prompt.replace('--', '')} --rt {request.aspect_ratio} --dur {request.duration} --rs 1080p"
 
         payload = {
             "model": "doubao-seedance-1-0-lite-t2v-250428",
@@ -141,8 +182,8 @@ async def create_task(request: Union[CompletionRequest, VideoRequest], api_key:
                 ]
             }
 
-        payload['model'] = "doubao-seedance-1-0-pro-250528"  # 未来注销
-
+        if "-pro" in request.model:
+            payload['model'] = "doubao-seedance-1-0-pro-250528"  # 未来注销
     else:
 
         payload = {
@@ -192,11 +233,12 @@ async def create_task(request: Union[CompletionRequest, VideoRequest], api_key:
     return response  # {'id': 'cgt-20250611152553-r46ql'}
 
 
-async def get_task(task_id: str):
-    token = await redis_aclient.get(task_id)  # 绑定对应的 token
-    api_key = token and token.decode()
-    if not token:
-        raise HTTPException(status_code=404, detail="TaskID not found")
+async def get_task(task_id: str, api_key: Optional[str] = None):
+    if api_key is None:
+        token = api_key or await redis_aclient.get(task_id)  # 绑定对应的 token
+        api_key = token and token.decode()
+        if not token:
+            raise HTTPException(status_code=404, detail="TaskID not found")
 
     client = AsyncClient(base_url="https://ark.cn-beijing.volces.com/api/v3", api_key=api_key)
 
@@ -280,9 +322,6 @@ c4356b58-4aa3-4a52-b907-b40c4dd2e502
     # arun(get_task_from_feishu(ids, tokens))
     # arun(get_task_from_feishu(ids, ))
 
-    # arun(get_valid_token(['a93ea9a5-3831-47b8-863a-57e10233f922']))
-    # arun(get_valid_token(batch_size=2))
-    # arun(get_valid_token(batch_size=2, seed=int(time.time())))
     arun(get_valid_token())
 
 """
