@@ -77,6 +77,9 @@ class ImagesResponse(_ImagesResponse):
 
             self.data = [{"url": image} for image in self.image]
 
+        elif self.data and "imageURL" in self.data[0]:
+            self.image = [d["imageURL"] for d in self.data]
+
     # class Config:
     #     extra = "allow"
 
@@ -148,9 +151,6 @@ class ImageRequest(BaseModel):  # openai
                 self.size = self.aspect_ratio = None
 
             elif self.size:  # 适配尺寸
-                # if self.size.lower().endswith('k'):
-                #     size = int(self.size.lower().split('k')[0]) * 1024
-                #     self.size = f"{size}x{size}"
                 self.aspect_ratio = size2aspect_ratio(self.size)
                 self.size = self.size if 'x' in self.size else '512x512'
 
@@ -704,4 +704,9 @@ if __name__ == '__main__':
 
     # print(request)
 
-    print(dict(Image()))
\ No newline at end of file
+    # print(dict(Image()))
+
+    print(ImageRequest(aspect_ratio="2:1"))
+    print(ImageRequest(size="8x2", aspect_ratio="2:1"))  # aspect_ratio优先级更高
+    print(ImageRequest(size="8x2"))
+    print(ImageRequest(size="8:2"))
