@@ -101,7 +101,7 @@ class ChannelInfo(BaseModel):
         self.id = self.id or None
 
         self.name = f"""{str(datetime.datetime.now())[:10]} {self.name or self.base_url or "NAME"}"""
-        self.tag = f"""{str(datetime.datetime.now())[:10]} {self.tag or self.base_url or "TAG"}"""
+        self.tag = f"""{self.tag or self.base_url or "TAG"}"""
         self.group = self.group or self.base_url or "GROUP"
 
         self.setting = self.setting or ""
@@ -136,3 +136,6 @@ if __name__ == '__main__':
     # option()
     #
     # arun(channel.edit_channel(MODEL_PRICE))
+
+
+
