@@ -61,7 +61,6 @@ class Video(_Video):
 
         self.status = to_status(self.status) or "queued"
 
-
         # if self.metadata and not self.video_url: # todo 解析 结果
         #     self.video_url = self.metadata.get("video_url")
 
@@ -125,17 +124,34 @@ class SoraVideoRequest(BaseModel):
 
     metadata: Optional[dict] = None
 
+    image: Optional[Union[str, List[str]]] = None  # url
+    first_frame_image: Optional[str] = None
+    last_frame_image: Optional[str] = None
+
     def __init__(self, /, **data: Any):
         super().__init__(**data)
         if self.input_reference and not isinstance(self.input_reference, list):
             self.input_reference = [self.input_reference]
 
+        if self.image and not isinstance(self.image, list):
+            self.image = [self.image]
+
+        if not self.input_reference:
+            if not self.first_frame_image:
+                self.first_frame_image = self.image[0] if self.image else None
+
+            if not self.last_frame_image:
+                self.last_frame_image = self.image[1] if self.image and len(self.image) > 0 else None
+
         if self.size:
             self.ratio = size2aspect_ratio(self.size)
 
         if not self.resolution and '_' in self.model and self.model.endswith('p'):  # _480p
             self.model, self.resolution = self.model.split('_', maxsplit=1)
 
+    class Config:
+        extra = "allow"
+
 
 class FalVideoRequest(BaseModel):
     model: Union[str, Literal["latentsync", "sync-lipsync",]] = 'latentsync'
@@ -178,10 +194,13 @@ if __name__ == '__main__':
 
     # print(Video(x=1))
 
-    # print(SoraVideoRequest(
-    #     model="doubao-seedance-1-0-pro-fast-251015_1080p",
-    #     input_reference="https://example.com/image.jpg"
-    # ))
+    print(SoraVideoRequest(
+        model="doubao-seedance-1-0-pro-fast-251015_1080p",
+        input_reference="https://example.com/image.jpg",
+
+        size="1x1",
+        xx=11111111
+    ))
 
     data = {'id': 'cgt-20250613160030-2dvd7',
             'model': 'doubao-seedance-1-0-pro-250528',
@@ -192,8 +211,8 @@ if __name__ == '__main__':
             'created_at': 1749801631,
             'updated_at': 1749801680}
 
-    _ = Video(
-        **data
-    )
-
-    print(_)
+    # _ = Video(
+    #     **data
+    # )
+    #
+    # print(_)
