@@ -114,6 +114,7 @@ def parse_url(text: str, for_image=False, fn: Optional[Callable] = None):
 def parse_url_from_json():
     pass
 
+
 def parse_command_string(command_str: str) -> dict:
     """
     解析一个类似 "prompt --key1 value1 --key2 value2" 格式的字符串。
@@ -188,6 +189,16 @@ def parse_command_string(command_str: str) -> dict:
     return result
 
 
+def parse_base64(text, pattern=r'!\[.*?\]\((.*?)\)'):
+    """
+    :param text:
+    :param pattern:
+        pattern=r'!\[.*?\]\((data:image/.*?)\)'
+    :return:
+    """
+    base64_strings = re.findall(pattern, text)
+    return base64_strings
+
 
 if __name__ == '__main__':
     # from urllib.parse import urlparse
@@ -258,7 +269,6 @@ https://i.miji.bid/2025/06/10/d018000aed9b872c7b248dccf14c4450.pngA
     """
     print(parse_url(text, for_image=True))
 
-
     # print(parse_url(text, for_image=False))
 
     # text = """https://photog.art/api/oss/R2yh8N Convert this portrait into a straight-on,front-facing ID-style headshot."""
@@ -266,4 +276,9 @@ https://i.miji.bid/2025/06/10/d018000aed9b872c7b248dccf14c4450.pngA
     #
     # valid_urls = parse_url(text, for_image=True)
 
-    print(mimetypes.guess_type("xx.ico"))
\ No newline at end of file
+    print(mimetypes.guess_type("xx.ico"))
+
+    text = "这是一个示例文本，包含一个图片：![image](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAABAAAAAQACAIAAADwf7zUAAAgAElEQ) 这张图片很棒。"
+    # text = "这是一个示例文本，。"
+
+    print(parse_base64(text * 2))
